Documentation
¶
Index ¶
- func CustomListenAndServeTLS(d *http.ServeMux) error
- func GenerateCertificate(host string) (key, certificate []byte)
- func JsonReader(r io.Reader) error
- func LogReader(r io.Reader)
- func MakeHttpClient() *http.Client
- func TarDir(path string) io.Reader
- type Container
- type Docker
- func (D *Docker) Build(fd io.Reader, name string) (i *Image, err error)
- func (D *Docker) GetIP() string
- func (D *Docker) ListContainers() (c []*Container, err error)
- func (D *Docker) ListImages() (img []*Image, err error)
- func (D *Docker) Load(imagename string) (I *Image, err error)
- func (D *Docker) Update()
- type EncWriter
- type HttpAPI
- func (h *HttpAPI) Delete(url string) (resp *http.Response, err error)
- func (h *HttpAPI) Get(url string) (resp *http.Response, err error)
- func (h *HttpAPI) Post(url string, content string, b io.Reader) (resp *http.Response, err error)
- func (h *HttpAPI) PostHeader(url string, content string, b io.Reader, header http.Header) (resp *http.Response, err error)
- func (h *HttpAPI) Put(url string, content string, b io.Reader) (resp *http.Response, err error)
- type Image
- func (Img *Image) AddTag(D *Docker, tag string) (err error)
- func (I *Image) GetName() (name string)
- func (Img *Image) IsRunning(D *Docker, imagename string) (running bool, C *Container, err error)
- func (Img *Image) Push(D *Docker, w io.Writer, name string) (err error)
- func (Img *Image) Run(D *Docker, env []string, port string) (C *Container, err error)
- func (Img *Image) Stop(D *Docker, imagename string)
- type Message
- type Multiplexer
- type PortBinding
- type SkeletonDeployment
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CustomListenAndServeTLS ¶
func GenerateCertificate ¶
func JsonReader ¶
func MakeHttpClient ¶
Types ¶
type Container ¶
type Container struct {
Id string
Image string
D *Docker
NetworkSettings struct {
Ports map[string][]map[string]string
}
Volumes map[string]string
Binds []string
PortBindings map[string][]PortBinding
}
func (*Container) AddExposedPort ¶
type Docker ¶
type Docker struct {
Containers []*Container
Images []*Image
Updated time.Time
// contains filtered or unexported fields
}
func (*Docker) ListContainers ¶
ListContainers gives the state for a specific docker container
func (*Docker) ListImages ¶
ListImages gives the state of the images for a specific Docker container
type EncWriter ¶
type EncWriter struct {
// contains filtered or unexported fields
}
func NewEncWriter ¶
type HttpAPI ¶
type HttpAPI struct {
// contains filtered or unexported fields
}
func NewHttpClient ¶
function to initialize new http struct
func (*HttpAPI) Delete ¶
Delete function to clean up http.NewRequest("DELETE"...) call, method for http struct
type Image ¶
type Image struct {
Id string
Tag string
Repository string
// contains filtered or unexported fields
}
func NewNamedImage ¶
type Multiplexer ¶
type Multiplexer struct {
// contains filtered or unexported fields
}
func NewMultiplexer ¶
func NewMultiplexer() *Multiplexer
func (*Multiplexer) Attach ¶
func (m *Multiplexer) Attach(w io.Writer)
func (*Multiplexer) Detach ¶
func (m *Multiplexer) Detach(w io.Writer)
type PortBinding ¶
Click to show internal directories.
Click to hide internal directories.